/*
 * Copyright (c) 2020, salesforce.com, inc.
 * All rights reserved.
 * SPDX-License-Identifier: BSD-3-Clause
 * For full license text, see the LICENSE file in the repo root or https://opensource.org/licenses/BSD-3-Clause
 */
import { BaseClient, ClientConfig, Response } from "@commerce-apps/core";
import { OperationOptions } from "retry";
export declare namespace ShopperBaskets {
  type ErrorResponse = {
    type: string;
    title?: string;
    detail?: string;
    instance?: string;
  } & {
    [key: string]: any;
  };
  type Money = {
    currencyMnemonic?: string;
    value?: number;
  } & {
    [key: string]: any;
  };
  type SimpleSearchResult = {
    limit: number;
    hits?: Array<object>;
    offset: number;
    total: number;
  } & {
    [key: string]: any;
  };
  type SearchRequest = {
    limit?: number;
    query: any;
    sorts?: Array<object>;
    offset?: number;
  } & {
    [key: string]: any;
  };
  type PaginatedSearchResult = {
    sorts?: Array<object>;
    hits?: Array<object>;
    query: any;
    limit: number;
    offset: number;
    total: number;
  } & {
    [key: string]: any;
  };
  type ClosedObject = {};
  type OpenObject = {} & {
    [key: string]: any;
  };
  type NoPropertiesAllowed = {};
  type SpecifiedPropertiesAllowed = {} & {
    [key: string]: any;
  };
  type MoneyMnemonic = {
    currencyMnemonic?: string;
    value?: number;
  } & {
    [key: string]: any;
  };
  type BoolFilter = {
    filters?: Array<any>;
    operator: string;
  } & {
    [key: string]: any;
  };
  type PaginatedSearchResultBase = {
    sorts?: Array<object>;
    hits?: Array<object>;
    query: any;
    limit: number;
    offset: number;
    total: number;
  } & {
    [key: string]: any;
  };
  type MatchAllQuery = {} & {
    [key: string]: any;
  };
  type FilteredQuery = {
    filter: any;
    query: any;
  } & {
    [key: string]: any;
  };
  type QueryFilter = {
    query: any;
  } & {
    [key: string]: any;
  };
  type Query = {
    boolQuery?: {
      must?: Array<any>;
      mustNot?: Array<any>;
      should?: Array<any>;
    } & {
      [key: string]: any;
    };
    filteredQuery?: {
      filter: any;
      query: any;
    } & {
      [key: string]: any;
    };
    matchAllQuery?: {} & {
      [key: string]: any;
    };
    nestedQuery?: {
      path: string;
      query: any;
      scoreMode?: string;
    } & {
      [key: string]: any;
    };
    termQuery?: {
      fields: Array<string>;
      operator: string;
      values?: Array<any>;
    } & {
      [key: string]: any;
    };
    textQuery?: {
      fields: Array<string>;
      searchPhrase: string;
    } & {
      [key: string]: any;
    };
  } & {
    [key: string]: any;
  };
  type TermQuery = {
    fields: Array<string>;
    operator: string;
    values?: Array<any>;
  } & {
    [key: string]: any;
  };
  type TermFilter = {
    field: string;
    operator: string;
    values?: Array<any>;
  } & {
    [key: string]: any;
  };
  type TextQuery = {
    fields: Array<string>;
    searchPhrase: string;
  } & {
    [key: string]: any;
  };
  type Range2Filter = {
    filterMode?: string;
    fromField: string;
    fromInclusive?: boolean;
    fromValue?: any;
    toField: string;
    toInclusive?: boolean;
    toValue?: any;
  } & {
    [key: string]: any;
  };
  type BoolQuery = {
    must?: Array<any>;
    mustNot?: Array<any>;
    should?: Array<any>;
  } & {
    [key: string]: any;
  };
  type SimpleSearchResultBase = {
    limit: number;
    hits?: Array<object>;
    offset: number;
    total: number;
  } & {
    [key: string]: any;
  };
  type NestedQuery = {
    path: string;
    query: any;
    scoreMode?: string;
  } & {
    [key: string]: any;
  };
  type Filter = {
    boolFilter?: {
      filters?: Array<any>;
      operator: string;
    } & {
      [key: string]: any;
    };
    queryFilter?: {
      query: any;
    } & {
      [key: string]: any;
    };
    range2Filter?: {
      filterMode?: string;
      fromField: string;
      fromInclusive?: boolean;
      fromValue?: any;
      toField: string;
      toInclusive?: boolean;
      toValue?: any;
    } & {
      [key: string]: any;
    };
    rangeFilter?: {
      field: string;
      from?: any;
      fromInclusive?: boolean;
      to?: any;
      toInclusive?: boolean;
    } & {
      [key: string]: any;
    };
    termFilter?: {
      field: string;
      operator: string;
      values?: Array<any>;
    } & {
      [key: string]: any;
    };
  } & {
    [key: string]: any;
  };
  type Sort = {
    field: string;
    sortOrder?: string;
  } & {
    [key: string]: any;
  };
  type RangeFilter = {
    field: string;
    from?: any;
    fromInclusive?: boolean;
    to?: any;
    toInclusive?: boolean;
  } & {
    [key: string]: any;
  };
  type SearchRequestBase = {
    limit?: number;
    query: any;
    sorts?: Array<object>;
    offset?: number;
  } & {
    [key: string]: any;
  };
  type TaxItems = {
    taxItems?: Array<object>;
  } & {
    [key: string]: any;
  };
  type PaymentCardSpec = {
    name?: string;
    numberLengths?: Array<string>;
    checksumVerificationEnabled?: boolean;
    numberPrefixes?: Array<string>;
    image?: string;
    cardType?: string;
    description?: string;
  } & {
    [key: string]: any;
  };
  type OrderAddress = {
    address1?: string;
    countryCode?: string;
    suffix?: string;
    jobTitle?: string;
    lastName?: string;
    fullName?: string;
    companyName?: string;
    id?: string;
    title?: string;
    firstName?: string;
    stateCode?: string;
    postBox?: string;
    secondName?: string;
    salutation?: string;
    phone?: string;
    suite?: string;
    city?: string;
    address2?: string;
    postalCode?: string;
  } & {
    [key: string]: any;
  };
  type BasketsResult = {
    baskets: Array<object>;
    total: number;
  } & {
    [key: string]: any;
  };
  type PaymentCard = {
    creditCardExpired?: boolean;
    validFromMonth?: number;
    creditCardToken?: string;
    expirationYear?: number;
    expirationMonth?: number;
    numberLastDigits?: string;
    cardType?: string;
    maskedNumber?: string;
    holder?: string;
    issueNumber?: string;
    validFromYear?: number;
  };
  type NotesResult = {
    notes?: Array<object>;
  } & {
    [key: string]: any;
  };
  type ShippingItem = {
    priceAdjustments?: Array<object>;
    taxBasis?: number;
    basePrice?: number;
    adjustedTax?: number;
    priceAfterItemDiscount?: number;
    taxRate?: number;
    itemText?: string;
    taxClassId?: string;
    itemId?: string;
    shipmentId?: string;
    price?: number;
    tax?: number;
  } & {
    [key: string]: any;
  };
  type Discount = {
    priceBookId?: string;
    amount?: number;
    type: string;
    percentage?: number;
  } & {
    [key: string]: any;
  };
  type Note = {
    subject?: string;
    createdBy?: string;
    id?: string;
    text?: string;
    creationDate?: any;
  };
  type CouponItem = {
    valid?: boolean;
    code: string;
    statusCode?: string;
    couponItemId?: string;
  } & {
    [key: string]: any;
  };
  type PromotionLink = {
    promotionId?: string;
    name?: string;
    title?: string;
    calloutMsg?: string;
  };
  type ShippingPromotion = {
    promotionName?: string;
    promotionId?: string;
    calloutMsg?: string;
  } & {
    [key: string]: any;
  };
  type ProductItem = {
    priceAdjustments?: Array<object>;
    taxBasis?: number;
    basePrice?: number;
    priceAfterOrderDiscount?: number;
    bundledProductItems?: Array<any>;
    adjustedTax?: number;
    taxRate?: number;
    priceAfterItemDiscount?: number;
    optionItems?: Array<object>;
    itemText?: string;
    taxClassId?: string;
    productListItem?: {
      productList?: {
        description?: string;
        name?: string;
        public?: boolean;
        title?: string;
        type?: string;
      } & {
        [key: string]: any;
      };
      productDetailsLink?: {
        title?: string;
        productDescription?: string;
        productId: string;
        productName?: string;
      };
      id: string;
      purchasedQuantity?: number;
      public?: boolean;
      type?: string;
      priority?: number;
      quantity?: number;
    };
    gift?: boolean;
    itemId?: string;
    productId?: string;
    shipmentId?: string;
    inventoryId?: string;
    shippingItemId?: string;
    giftMessage?: string;
    bonusProductLineItem?: boolean;
    price?: number;
    bonusDiscountLineItemId?: string;
    tax?: number;
    productName?: string;
    quantity?: number;
  } & {
    [key: string]: any;
  };
  type BasketPaymentInstrumentRequest = {
    bankRoutingNumber?: string;
    amount?: number;
    paymentMethodId?: string;
    giftCertificateCode?: string;
    paymentCard?: {
      validFromMonth?: number;
      creditCardToken?: string;
      expirationYear?: number;
      expirationMonth?: number;
      cardType?: string;
      maskedNumber?: string;
      holder?: string;
      issueNumber?: string;
      validFromYear?: number;
    };
  } & {
    [key: string]: any;
  };
  type Taxes = {
    taxes: {} & {
      [key: string]: any;
    };
  };
  type OrderPaymentInstrument = {
    amount?: number;
    authorizationStatus?: {
      code?: string;
      message?: string;
      status?: number;
    };
    bankRoutingNumber?: string;
    maskedGiftCertificateCode?: string;
    paymentCard?: {
      creditCardExpired?: boolean;
      validFromMonth?: number;
      creditCardToken?: string;
      expirationYear?: number;
      expirationMonth?: number;
      numberLastDigits?: string;
      cardType?: string;
      maskedNumber?: string;
      holder?: string;
      issueNumber?: string;
      validFromYear?: number;
    };
    paymentInstrumentId?: string;
    paymentMethodId?: string;
  } & {
    [key: string]: any;
  };
  type BonusDiscountLineItem = {
    promotionId?: string;
    id?: string;
    bonusProducts?: Array<object>;
    couponCode?: string;
    maxBonusItems?: number;
  } & {
    [key: string]: any;
  };
  type PaymentMethodResult = {
    applicablePaymentMethods?: Array<object>;
  } & {
    [key: string]: any;
  };
  type Shipment = {
    shippingStatus?: string;
    productTotal?: number;
    shipmentNo?: string;
    productSubTotal?: number;
    shippingTotal?: number;
    merchandizeTotalTax?: number;
    trackingNumber?: string;
    shippingTotalTax?: number;
    shippingMethod?: {
      name?: string;
      shippingPromotions?: Array<object>;
      externalShippingMethod?: string;
      id: string;
      price?: number;
      description?: string;
    } & {
      [key: string]: any;
    };
    gift?: boolean;
    shippingAddress?: {
      address1?: string;
      countryCode?: string;
      suffix?: string;
      jobTitle?: string;
      lastName?: string;
      fullName?: string;
      companyName?: string;
      id?: string;
      title?: string;
      firstName?: string;
      stateCode?: string;
      postBox?: string;
      secondName?: string;
      salutation?: string;
      phone?: string;
      city?: string;
      suite?: string;
      address2?: string;
      postalCode?: string;
    } & {
      [key: string]: any;
    };
    taxTotal?: number;
    shipmentId?: string;
    adjustedMerchandizeTotalTax?: number;
    adjustedShippingTotalTax?: number;
    giftMessage?: string;
    shipmentTotal?: number;
  } & {
    [key: string]: any;
  };
  type CustomerInfo = {
    customerName?: string;
    customerNo?: string;
    email: string;
    customerId?: string;
  } & {
    [key: string]: any;
  };
  type SimpleLink = {};
  type PriceAdjustment = {
    appliedDiscount?: {
      priceBookId?: string;
      amount?: number;
      type: string;
      percentage?: number;
    } & {
      [key: string]: any;
    };
    lastModified?: any;
    promotionId?: string;
    createdBy?: string;
    custom?: boolean;
    itemText?: string;
    manual?: boolean;
    priceAdjustmentId?: string;
    couponCode?: string;
    price?: number;
    creationDate?: any;
    promotionLink?: string;
    reasonCode?: string;
  } & {
    [key: string]: any;
  };
  type ShippingMethodResult = {
    applicableShippingMethods?: Array<object>;
    defaultShippingMethodId?: string;
  } & {
    [key: string]: any;
  };
  type ProductDetailsLink = {
    title?: string;
    productDescription?: string;
    productId: string;
    productName?: string;
  };
  type OptionItem = {
    taxBasis?: number;
    priceAdjustments?: Array<object>;
    basePrice?: number;
    priceAfterOrderDiscount?: number;
    bundledProductItems?: Array<any>;
    adjustedTax?: number;
    taxRate?: number;
    priceAfterItemDiscount?: number;
    optionItems?: Array<any>;
    taxClassId?: string;
    itemText?: string;
    productListItem?: {
      productList?: {
        description?: string;
        name?: string;
        public?: boolean;
        title?: string;
        type?: string;
      } & {
        [key: string]: any;
      };
      productDetailsLink?: {
        title?: string;
        productDescription?: string;
        productId: string;
        productName?: string;
      };
      id: string;
      purchasedQuantity?: number;
      public?: boolean;
      type?: string;
      priority?: number;
      quantity?: number;
    };
    gift?: boolean;
    itemId?: string;
    productId?: string;
    optionId: string;
    shipmentId?: string;
    inventoryId?: string;
    shippingItemId?: string;
    giftMessage?: string;
    bonusProductLineItem?: boolean;
    optionValueId: string;
    price?: number;
    bonusDiscountLineItemId?: string;
    tax?: number;
    productName?: string;
    quantity?: number;
  } & {
    [key: string]: any;
  };
  type ShippingMethod = {
    name?: string;
    shippingPromotions?: Array<object>;
    externalShippingMethod?: string;
    id: string;
    price?: number;
    description?: string;
  } & {
    [key: string]: any;
  };
  type Basket = {
    shipments?: Array<object>;
    giftCertificateItems?: Array<object>;
    bonusDiscountLineItems?: Array<object>;
    productTotal?: number;
    sourceCode?: string;
    lastModified?: any;
    agentBasket?: boolean;
    productSubTotal?: number;
    couponItems?: Array<object>;
    shippingItems?: Array<object>;
    shippingTotal?: number;
    customerInfo?: {
      customerName?: string;
      customerNo?: string;
      email: string;
      customerId?: string;
    } & {
      [key: string]: any;
    };
    merchandizeTotalTax?: number;
    shippingTotalTax?: number;
    taxation?: string;
    paymentInstruments?: Array<object>;
    notes?: {};
    inventoryReservationExpiry?: any;
    taxTotal?: number;
    orderTotal?: number;
    currency?: string;
    adjustedShippingTotalTax?: number;
    adjustedMerchandizeTotalTax?: number;
    basketId?: string;
    billingAddress?: {
      address1?: string;
      countryCode?: string;
      suffix?: string;
      jobTitle?: string;
      lastName?: string;
      fullName?: string;
      companyName?: string;
      id?: string;
      title?: string;
      firstName?: string;
      stateCode?: string;
      postBox?: string;
      secondName?: string;
      salutation?: string;
      phone?: string;
      suite?: string;
      city?: string;
      address2?: string;
      postalCode?: string;
    } & {
      [key: string]: any;
    };
    creationDate?: any;
    productItems?: Array<object>;
    orderPriceAdjustments?: Array<object>;
    channelType?: string;
  } & {
    [key: string]: any;
  };
  type OrderPaymentInstrumentRequest = {
    bankRoutingNumber?: string;
    amount?: number;
    paymentMethodId?: string;
    giftCertificateCode?: string;
    paymentCard?: {
      creditCardToken?: string;
      validFromMonth?: number;
      expirationMonth?: number;
      expirationYear?: number;
      cardType?: string;
      holder?: string;
      maskedNumber?: string;
      issueNumber?: string;
      validFromYear?: number;
    };
  } & {
    [key: string]: any;
  };
  type GiftCertificateItem = {
    recipientName?: string;
    senderName?: string;
    recipientEmail: string;
    amount: number;
    shipmentId?: string;
    message?: string;
    giftCertificateItemId?: string;
  } & {
    [key: string]: any;
  };
  type ProductListLink = {
    description?: string;
    name?: string;
    public?: boolean;
    title?: string;
    type?: string;
  } & {
    [key: string]: any;
  };
  type Order = {
    adjustedMerchandizeTotalTax?: number;
    adjustedShippingTotalTax?: number;
    billingAddress?: {
      address1?: string;
      countryCode?: string;
      suffix?: string;
      jobTitle?: string;
      lastName?: string;
      fullName?: string;
      companyName?: string;
      id?: string;
      title?: string;
      firstName?: string;
      stateCode?: string;
      postBox?: string;
      secondName?: string;
      salutation?: string;
      phone?: string;
      suite?: string;
      city?: string;
      address2?: string;
      postalCode?: string;
    } & {
      [key: string]: any;
    };
    bonusDiscountLineItems?: Array<object>;
    channelType?: string;
    confirmationStatus?: string;
    couponItems?: Array<object>;
    createdBy?: string;
    creationDate?: any;
    currency?: string;
    customerInfo?: {
      customerName?: string;
      customerNo?: string;
      email: string;
      customerId?: string;
    } & {
      [key: string]: any;
    };
    customerName?: string;
    exportStatus?: string;
    externalOrderStatus?: string;
    giftCertificateItems?: Array<object>;
    globalPartyId?: string;
    lastModified?: any;
    merchandizeTotalTax?: number;
    notes?: {};
    orderNo?: string;
    orderPriceAdjustments?: Array<object>;
    orderToken?: string;
    orderTotal?: number;
    paymentInstruments?: Array<object>;
    paymentStatus?: string;
    productItems?: Array<object>;
    productSubTotal?: number;
    productTotal?: number;
    shipments?: Array<object>;
    shippingItems?: Array<object>;
    shippingStatus?: string;
    shippingTotal?: number;
    shippingTotalTax?: number;
    siteId?: string;
    sourceCode?: string;
    status?: string;
    taxTotal?: number;
    taxation?: string;
  } & {
    [key: string]: any;
  };
  type OrderPaymentCardRequest = {
    validFromMonth?: number;
    creditCardToken?: string;
    expirationYear?: number;
    expirationMonth?: number;
    cardType?: string;
    maskedNumber?: string;
    holder?: string;
    issueNumber?: string;
    validFromYear?: number;
  };
  type PaymentMethod = {
    name?: string;
    id: string;
    image?: string;
    paymentProcessorId?: string;
    description?: string;
    cards?: Array<object>;
  } & {
    [key: string]: any;
  };
  type TaxItem = {
    id: string;
    value?: number;
    rate: number;
  };
  type Status = {
    code?: string;
    message?: string;
    status?: number;
  };
  type ProductListItemReference = {
    productList?: {
      description?: string;
      name?: string;
      public?: boolean;
      title?: string;
      type?: string;
    } & {
      [key: string]: any;
    };
    productDetailsLink?: {
      title?: string;
      productDescription?: string;
      productId: string;
      productName?: string;
    };
    id: string;
    purchasedQuantity?: number;
    public?: boolean;
    type?: string;
    priority?: number;
    quantity?: number;
  };
}
/**
 * [Shopper Baskets](https://developer.commercecloud.com/s/api-details/a003k00000UHvpEAAT)
 * ==================================
 * *Build a checkout experience.*<br />
 *
 * Simple example:
 *
 * ```typescript
 *   import { Checkout, ClientConfig } from "commerce-sdk";
 *   // or
 *   const { Checkout, ClientConfig } = require("commerce-sdk");
 *
 *   const clientConfig: ClientConfig = { ... };
 *   const shopperBasketsClient = new Checkout.ShopperBaskets(clientConfig);
 * ```
 *
 * Example with shopper auth
 * ```typescript
 * const clientConfig: ClientConfig = {
 *   parameters: {
 *     clientId: "XXXXXX",
 *     organizationId: "XXXX",
 *     shortCode: "XXX",
 *     siteId: "XX"
 *   }
 * };
 * token = await helpers.getShopperToken(clientConfig, { type: "guest" });
 * clientConfig.headers["authorization"] = token.getBearerHeader();
 * const shopperBasketsClient = new Checkout.ShopperBaskets(clientConfig);
 * ```
 *
 * <span style="font-size:.7em; display:block; text-align: right">
 * API Version: 0.1.2<br />
 * Last Updated: 2020-07-14T08:32:32.726Z<br />
 * </span>
 */
export declare class ShopperBaskets extends BaseClient {
  constructor(config: ClientConfig);
  /**
    * Creates a new basket.

The created basket is initialized with default values. Data provided in the body document is populated into the created basket. It can be updated with API endpoints listed below.

The taxMode query parameter can be used to choose the basket tax mode. The default is internal, in which case the tax calculation is done automatically based on internal tax tables. Alternatively, external taxation mode can be set which allows manual modification of the tax rates and values. External tax data is mandatory for product line items, option line items, shipping line items, coupon line items, and bonus discount line item. Gift certificate line items are optional and use zero tax rate per default, which can be overwritten. Price adjustments cannot be set because they are either calculated or inherited (depending on the type, the tax rate is either obtained from the related line item or computed as prorate of the basket).

API endpoints allowing further basket modification:

- customer information: PUT /baskets/\{basketId\}/customer

- billing address: PUT /baskets/\{basketId\}/billing-address

- shipments including shipping address and shipping method: POST /baskets/\{basketId\}/shipments

- product items: POST /baskets/\{basketId\}/items

- coupon items: POST /baskets/\{basketId\}/coupons

- gift certificate items: POST /baskets/\{basketId\}/gift-certificates

- basket taxation: PUT /baskets/\{basketId\}/taxes

- basket item taxation: PUT /baskets/\{basketId\}/items/\{itemId\}/taxes

- payment method and card type: POST /baskets/\{basketId\}/payment-instruments

- custom properties: PATCH /baskets/\{basketId\}

Related resource means with which resource you can specify the same data after the basket creation.
Identify the basket using the basketId property, which
should be integrated into the path of an update request (for example a POST to
/baskets/\{basketId\}/items).

A customer must provide a JSON Web Token (JWT), which specifies exactly one customer (it can be a guest or a registered
customer). In this case, the resource creates a basket for this customer.

The number of baskets which can be created per customer is limited. When a
basket is created, it is said to be open. It remains open until either an order is created from it
using a POST to resource /orders, or it is deleted using a DELETE to resource
/baskets/\{basketId\}. Each customer can have just one open basket.

Custom properties in the form c_\<CUSTOM_NAME\> are supported. A custom property must correspond to a custom
attribute (\<CUSTOM_NAME\>) defined for the basket system object, and its value must be valid for that custom
attribute.
    *
    * If you would like to get a raw Response object use the other createBasket function.
    *
    * @param options - An object containing the options for this method.
    * @param parameters - An object containing the parameters for this method.
    * @param organizationId - An identifier for the organization the request is being made by.
    * @param taxMode -
    * @param siteId -
    * @param headers - An object literal of key value pairs of the headers to be
    * sent with this request.
    * @param body - The data to send as the request body.
    *
    * @returns A promise of type ShopperBaskets.Basket.
    */
  createBasket(options: {
    parameters?: {
      organizationId?: string;
      taxMode?: string;
      siteId?: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
    body: ShopperBaskets.Basket;
  }): Promise<ShopperBaskets.Basket>;
  /**
    * Creates a new basket.

The created basket is initialized with default values. Data provided in the body document is populated into the created basket. It can be updated with API endpoints listed below.

The taxMode query parameter can be used to choose the basket tax mode. The default is internal, in which case the tax calculation is done automatically based on internal tax tables. Alternatively, external taxation mode can be set which allows manual modification of the tax rates and values. External tax data is mandatory for product line items, option line items, shipping line items, coupon line items, and bonus discount line item. Gift certificate line items are optional and use zero tax rate per default, which can be overwritten. Price adjustments cannot be set because they are either calculated or inherited (depending on the type, the tax rate is either obtained from the related line item or computed as prorate of the basket).

API endpoints allowing further basket modification:

- customer information: PUT /baskets/\{basketId\}/customer

- billing address: PUT /baskets/\{basketId\}/billing-address

- shipments including shipping address and shipping method: POST /baskets/\{basketId\}/shipments

- product items: POST /baskets/\{basketId\}/items

- coupon items: POST /baskets/\{basketId\}/coupons

- gift certificate items: POST /baskets/\{basketId\}/gift-certificates

- basket taxation: PUT /baskets/\{basketId\}/taxes

- basket item taxation: PUT /baskets/\{basketId\}/items/\{itemId\}/taxes

- payment method and card type: POST /baskets/\{basketId\}/payment-instruments

- custom properties: PATCH /baskets/\{basketId\}

Related resource means with which resource you can specify the same data after the basket creation.
Identify the basket using the basketId property, which
should be integrated into the path of an update request (for example a POST to
/baskets/\{basketId\}/items).

A customer must provide a JSON Web Token (JWT), which specifies exactly one customer (it can be a guest or a registered
customer). In this case, the resource creates a basket for this customer.

The number of baskets which can be created per customer is limited. When a
basket is created, it is said to be open. It remains open until either an order is created from it
using a POST to resource /orders, or it is deleted using a DELETE to resource
/baskets/\{basketId\}. Each customer can have just one open basket.

Custom properties in the form c_\<CUSTOM_NAME\> are supported. A custom property must correspond to a custom
attribute (\<CUSTOM_NAME\>) defined for the basket system object, and its value must be valid for that custom
attribute.
    *
    * @param options - An object containing the options for this method.
    * @param parameters - An object containing the parameters for this method.
    * @param organizationId - An identifier for the organization the request is being made by.
    * @param taxMode -
    * @param siteId -
    * @param headers - An object literal of key value pairs of the headers to be
    * sent with this request.
    * @param body - The data to send as the request body.
    * @param rawResponse - Set to true to return entire Response object instead of DTO.
    *
    * @returns A promise of type Response if rawResponse is true, a promise of type ShopperBaskets.Basket otherwise.
    */
  createBasket<T extends boolean>(
    options: {
      parameters?: {
        organizationId?: string;
        taxMode?: string;
        siteId?: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
      body: ShopperBaskets.Basket;
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : ShopperBaskets.Basket>;
  /**
   * Removes a basket.
   *
   * If you would like to get a raw Response object use the other deleteBasket function.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId - An identifier for the organization the request is being made by.
   * @param basketId - The ID of the basket to be modified.
   * @param siteId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   *
   * @returns A promise of type void.
   */
  deleteBasket(options?: {
    parameters?: {
      organizationId?: string;
      basketId: string;
      siteId?: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
  }): Promise<void>;
  /**
   * Removes a basket.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId - An identifier for the organization the request is being made by.
   * @param basketId - The ID of the basket to be modified.
   * @param siteId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type void otherwise.
   */
  deleteBasket<T extends boolean>(
    options?: {
      parameters?: {
        organizationId?: string;
        basketId: string;
        siteId?: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : void>;
  /**
   * Gets a basket.
   *
   * If you would like to get a raw Response object use the other getBasket function.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId - An identifier for the organization the request is being made by.
   * @param basketId - The ID of the basket to be modified.
   * @param siteId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   *
   * @returns A promise of type ShopperBaskets.Basket.
   */
  getBasket(options?: {
    parameters?: {
      organizationId?: string;
      basketId: string;
      siteId?: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
  }): Promise<ShopperBaskets.Basket>;
  /**
   * Gets a basket.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId - An identifier for the organization the request is being made by.
   * @param basketId - The ID of the basket to be modified.
   * @param siteId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type ShopperBaskets.Basket otherwise.
   */
  getBasket<T extends boolean>(
    options?: {
      parameters?: {
        organizationId?: string;
        basketId: string;
        siteId?: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : ShopperBaskets.Basket>;
  /**
    * Updates a basket. Only the currency of the basket, source code, the custom
properties of the basket, and the shipping items will be considered.
    *
    * If you would like to get a raw Response object use the other updateBasket function.
    *
    * @param options - An object containing the options for this method.
    * @param parameters - An object containing the parameters for this method.
    * @param organizationId - An identifier for the organization the request is being made by.
    * @param basketId - The ID of the basket to be modified.
    * @param siteId -
    * @param headers - An object literal of key value pairs of the headers to be
    * sent with this request.
    * @param body - The data to send as the request body.
    *
    * @returns A promise of type ShopperBaskets.Basket.
    */
  updateBasket(options: {
    parameters?: {
      organizationId?: string;
      basketId: string;
      siteId?: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
    body: ShopperBaskets.Basket;
  }): Promise<ShopperBaskets.Basket>;
  /**
    * Updates a basket. Only the currency of the basket, source code, the custom
properties of the basket, and the shipping items will be considered.
    *
    * @param options - An object containing the options for this method.
    * @param parameters - An object containing the parameters for this method.
    * @param organizationId - An identifier for the organization the request is being made by.
    * @param basketId - The ID of the basket to be modified.
    * @param siteId -
    * @param headers - An object literal of key value pairs of the headers to be
    * sent with this request.
    * @param body - The data to send as the request body.
    * @param rawResponse - Set to true to return entire Response object instead of DTO.
    *
    * @returns A promise of type Response if rawResponse is true, a promise of type ShopperBaskets.Basket otherwise.
    */
  updateBasket<T extends boolean>(
    options: {
      parameters?: {
        organizationId?: string;
        basketId: string;
        siteId?: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
      body: ShopperBaskets.Basket;
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : ShopperBaskets.Basket>;
  /**
   * Sets the billing address of a basket.
   *
   * If you would like to get a raw Response object use the other updateBillingAddressForBasket function.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId - An identifier for the organization the request is being made by.
   * @param basketId - The ID of the basket to be modified.
   * @param useAsShipping -
   * @param siteId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param body - The data to send as the request body.
   *
   * @returns A promise of type ShopperBaskets.Basket.
   */
  updateBillingAddressForBasket(options: {
    parameters?: {
      organizationId?: string;
      basketId: string;
      useAsShipping?: boolean;
      siteId?: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
    body: ShopperBaskets.OrderAddress;
  }): Promise<ShopperBaskets.Basket>;
  /**
   * Sets the billing address of a basket.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId - An identifier for the organization the request is being made by.
   * @param basketId - The ID of the basket to be modified.
   * @param useAsShipping -
   * @param siteId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param body - The data to send as the request body.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type ShopperBaskets.Basket otherwise.
   */
  updateBillingAddressForBasket<T extends boolean>(
    options: {
      parameters?: {
        organizationId?: string;
        basketId: string;
        useAsShipping?: boolean;
        siteId?: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
      body: ShopperBaskets.OrderAddress;
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : ShopperBaskets.Basket>;
  /**
   * Adds a coupon to an existing basket.
   *
   * If you would like to get a raw Response object use the other addCouponToBasket function.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId - An identifier for the organization the request is being made by.
   * @param basketId - The ID of the basket to be modified.
   * @param siteId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param body - The data to send as the request body.
   *
   * @returns A promise of type ShopperBaskets.Basket.
   */
  addCouponToBasket(options: {
    parameters?: {
      organizationId?: string;
      basketId: string;
      siteId?: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
    body: ShopperBaskets.CouponItem;
  }): Promise<ShopperBaskets.Basket>;
  /**
   * Adds a coupon to an existing basket.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId - An identifier for the organization the request is being made by.
   * @param basketId - The ID of the basket to be modified.
   * @param siteId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param body - The data to send as the request body.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type ShopperBaskets.Basket otherwise.
   */
  addCouponToBasket<T extends boolean>(
    options: {
      parameters?: {
        organizationId?: string;
        basketId: string;
        siteId?: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
      body: ShopperBaskets.CouponItem;
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : ShopperBaskets.Basket>;
  /**
   * Removes a coupon from the basket.
   *
   * If you would like to get a raw Response object use the other removeCouponFromBasket function.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId - An identifier for the organization the request is being made by.
   * @param basketId - The ID of the basket to be modified.
   * @param couponItemId - The ID of the coupon item to be removed.
   * @param siteId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   *
   * @returns A promise of type ShopperBaskets.Basket.
   */
  removeCouponFromBasket(options?: {
    parameters?: {
      organizationId?: string;
      basketId: string;
      couponItemId: string;
      siteId?: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
  }): Promise<ShopperBaskets.Basket>;
  /**
   * Removes a coupon from the basket.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId - An identifier for the organization the request is being made by.
   * @param basketId - The ID of the basket to be modified.
   * @param couponItemId - The ID of the coupon item to be removed.
   * @param siteId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type ShopperBaskets.Basket otherwise.
   */
  removeCouponFromBasket<T extends boolean>(
    options?: {
      parameters?: {
        organizationId?: string;
        basketId: string;
        couponItemId: string;
        siteId?: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : ShopperBaskets.Basket>;
  /**
   * Sets customer information for an existing basket.
   *
   * If you would like to get a raw Response object use the other updateCustomerForBasket function.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId - An identifier for the organization the request is being made by.
   * @param basketId - The ID of the basket to be modified.
   * @param siteId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param body - The data to send as the request body.
   *
   * @returns A promise of type ShopperBaskets.Basket.
   */
  updateCustomerForBasket(options: {
    parameters?: {
      organizationId?: string;
      basketId: string;
      siteId?: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
    body: ShopperBaskets.CustomerInfo;
  }): Promise<ShopperBaskets.Basket>;
  /**
   * Sets customer information for an existing basket.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId - An identifier for the organization the request is being made by.
   * @param basketId - The ID of the basket to be modified.
   * @param siteId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param body - The data to send as the request body.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type ShopperBaskets.Basket otherwise.
   */
  updateCustomerForBasket<T extends boolean>(
    options: {
      parameters?: {
        organizationId?: string;
        basketId: string;
        siteId?: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
      body: ShopperBaskets.CustomerInfo;
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : ShopperBaskets.Basket>;
  /**
   * Adds a gift certificate item to an existing basket.
   *
   * If you would like to get a raw Response object use the other addGiftCertificateItemToBasket function.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId - An identifier for the organization the request is being made by.
   * @param basketId - The ID of the basket to be modified.
   * @param siteId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param body - The data to send as the request body.
   *
   * @returns A promise of type ShopperBaskets.Basket.
   */
  addGiftCertificateItemToBasket(options: {
    parameters?: {
      organizationId?: string;
      basketId: string;
      siteId?: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
    body: ShopperBaskets.GiftCertificateItem;
  }): Promise<ShopperBaskets.Basket>;
  /**
   * Adds a gift certificate item to an existing basket.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId - An identifier for the organization the request is being made by.
   * @param basketId - The ID of the basket to be modified.
   * @param siteId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param body - The data to send as the request body.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type ShopperBaskets.Basket otherwise.
   */
  addGiftCertificateItemToBasket<T extends boolean>(
    options: {
      parameters?: {
        organizationId?: string;
        basketId: string;
        siteId?: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
      body: ShopperBaskets.GiftCertificateItem;
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : ShopperBaskets.Basket>;
  /**
   * Deletes a gift certificate item from an existing basket.
   *
   * If you would like to get a raw Response object use the other removeGiftCertificateItemFromBasket function.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId - An identifier for the organization the request is being made by.
   * @param basketId - The ID of the basket to be modified.
   * @param giftCertificateItemId - the ID of the gift certificate item to be updated.
   * @param siteId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   *
   * @returns A promise of type ShopperBaskets.Basket.
   */
  removeGiftCertificateItemFromBasket(options?: {
    parameters?: {
      organizationId?: string;
      basketId: string;
      giftCertificateItemId: string;
      siteId?: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
  }): Promise<ShopperBaskets.Basket>;
  /**
   * Deletes a gift certificate item from an existing basket.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId - An identifier for the organization the request is being made by.
   * @param basketId - The ID of the basket to be modified.
   * @param giftCertificateItemId - the ID of the gift certificate item to be updated.
   * @param siteId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type ShopperBaskets.Basket otherwise.
   */
  removeGiftCertificateItemFromBasket<T extends boolean>(
    options?: {
      parameters?: {
        organizationId?: string;
        basketId: string;
        giftCertificateItemId: string;
        siteId?: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : ShopperBaskets.Basket>;
  /**
   * Updates a gift certificate item of an existing basket.
   *
   * If you would like to get a raw Response object use the other updateGiftCertificateItemInBasket function.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId - An identifier for the organization the request is being made by.
   * @param basketId - The ID of the basket to be modified.
   * @param giftCertificateItemId - the ID of the gift certificate item to be updated.
   * @param siteId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param body - The data to send as the request body.
   *
   * @returns A promise of type ShopperBaskets.Basket.
   */
  updateGiftCertificateItemInBasket(options: {
    parameters?: {
      organizationId?: string;
      basketId: string;
      giftCertificateItemId: string;
      siteId?: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
    body: ShopperBaskets.GiftCertificateItem;
  }): Promise<ShopperBaskets.Basket>;
  /**
   * Updates a gift certificate item of an existing basket.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId - An identifier for the organization the request is being made by.
   * @param basketId - The ID of the basket to be modified.
   * @param giftCertificateItemId - the ID of the gift certificate item to be updated.
   * @param siteId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param body - The data to send as the request body.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type ShopperBaskets.Basket otherwise.
   */
  updateGiftCertificateItemInBasket<T extends boolean>(
    options: {
      parameters?: {
        organizationId?: string;
        basketId: string;
        giftCertificateItemId: string;
        siteId?: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
      body: ShopperBaskets.GiftCertificateItem;
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : ShopperBaskets.Basket>;
  /**
    * Adds new items to a basket. The added items are associated with the
specified shipment. If no shipment id is specified, the added items are associated with the default shipment.
Considered values from the request body, for each item are:

- productId: a valid product ID. This is the ID of the product to be added to the basket. If the
product is already in the basket, the API either increments the quantity of the existing product line item or
creates a new product line item, based on the site preference 'Add Product Behavior'. For option products and
product bundles containing variation masters, the API creates a new product line item regardless of the site
preference.
- shipmentId: a valid shipment ID (optional). This is the ID of the shipment in which the product item
is created.
- quantity: a number between 0.01 and 999. This is the quantity of the product to order.
- inventoryId: a valid inventory ID (optional). This is the ID of the inventory from which the item is
allocated.
- bonusDiscountLineItemId: a valid bonus discount line item ID (optional). This is the ID of the
bonus discount line item for which the added product is a selected bonus product.
- optionItems/optionValueId: a valid option value ID. This is an option value for an option item of
an option product.  This is only possible if the product item is an option
product. To set option values, you must specify a collection of option items in the optionItems
property. These option items must contain optionId and optionValueId. Also,
the values you specify must be valid for the option product that this product item represents. Otherwise, the
server throws an InvalidProductOptionItemException or an
InvalidProductOptionValueItemException.
- custom properties in the form c_\<CUSTOM_NAME\>: the custom property must correspond to a custom
attribute (\<CUSTOM_NAME\>) defined for ProductLineItem. The value of this property must be valid for the
type of custom attribute defined for ProductLineItem.
    *
    * If you would like to get a raw Response object use the other addItemToBasket function.
    *
    * @param options - An object containing the options for this method.
    * @param parameters - An object containing the parameters for this method.
    * @param organizationId - An identifier for the organization the request is being made by.
    * @param basketId - The ID of the basket to be modified.
    * @param siteId -
    * @param headers - An object literal of key value pairs of the headers to be
    * sent with this request.
    * @param body - The data to send as the request body.
    *
    * @returns A promise of type ShopperBaskets.Basket.
    */
  addItemToBasket(options: {
    parameters?: {
      organizationId?: string;
      basketId: string;
      siteId?: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
    body: Array<ShopperBaskets.ProductItem>;
  }): Promise<ShopperBaskets.Basket>;
  /**
    * Adds new items to a basket. The added items are associated with the
specified shipment. If no shipment id is specified, the added items are associated with the default shipment.
Considered values from the request body, for each item are:

- productId: a valid product ID. This is the ID of the product to be added to the basket. If the
product is already in the basket, the API either increments the quantity of the existing product line item or
creates a new product line item, based on the site preference 'Add Product Behavior'. For option products and
product bundles containing variation masters, the API creates a new product line item regardless of the site
preference.
- shipmentId: a valid shipment ID (optional). This is the ID of the shipment in which the product item
is created.
- quantity: a number between 0.01 and 999. This is the quantity of the product to order.
- inventoryId: a valid inventory ID (optional). This is the ID of the inventory from which the item is
allocated.
- bonusDiscountLineItemId: a valid bonus discount line item ID (optional). This is the ID of the
bonus discount line item for which the added product is a selected bonus product.
- optionItems/optionValueId: a valid option value ID. This is an option value for an option item of
an option product.  This is only possible if the product item is an option
product. To set option values, you must specify a collection of option items in the optionItems
property. These option items must contain optionId and optionValueId. Also,
the values you specify must be valid for the option product that this product item represents. Otherwise, the
server throws an InvalidProductOptionItemException or an
InvalidProductOptionValueItemException.
- custom properties in the form c_\<CUSTOM_NAME\>: the custom property must correspond to a custom
attribute (\<CUSTOM_NAME\>) defined for ProductLineItem. The value of this property must be valid for the
type of custom attribute defined for ProductLineItem.
    *
    * @param options - An object containing the options for this method.
    * @param parameters - An object containing the parameters for this method.
    * @param organizationId - An identifier for the organization the request is being made by.
    * @param basketId - The ID of the basket to be modified.
    * @param siteId -
    * @param headers - An object literal of key value pairs of the headers to be
    * sent with this request.
    * @param body - The data to send as the request body.
    * @param rawResponse - Set to true to return entire Response object instead of DTO.
    *
    * @returns A promise of type Response if rawResponse is true, a promise of type ShopperBaskets.Basket otherwise.
    */
  addItemToBasket<T extends boolean>(
    options: {
      parameters?: {
        organizationId?: string;
        basketId: string;
        siteId?: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
      body: Array<ShopperBaskets.ProductItem>;
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : ShopperBaskets.Basket>;
  /**
   * Removes a product item from the basket.
   *
   * If you would like to get a raw Response object use the other removeItemFromBasket function.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId - An identifier for the organization the request is being made by.
   * @param basketId - The ID of the basket to be modified.
   * @param itemId - The ID of the item to be updated.
   * @param siteId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   *
   * @returns A promise of type ShopperBaskets.Basket.
   */
  removeItemFromBasket(options?: {
    parameters?: {
      organizationId?: string;
      basketId: string;
      itemId: string;
      siteId?: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
  }): Promise<ShopperBaskets.Basket>;
  /**
   * Removes a product item from the basket.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId - An identifier for the organization the request is being made by.
   * @param basketId - The ID of the basket to be modified.
   * @param itemId - The ID of the item to be updated.
   * @param siteId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type ShopperBaskets.Basket otherwise.
   */
  removeItemFromBasket<T extends boolean>(
    options?: {
      parameters?: {
        organizationId?: string;
        basketId: string;
        itemId: string;
        siteId?: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : ShopperBaskets.Basket>;
  /**
    * Updates an item in a basket. The
following values in the request body are considered by the server:

- productId: a valid product ID. The purpose of this
value is to exchange a variation of a variation product.
- shipmentId: a valid shipment ID. The purpose of
this value is to move a product item to another shipment.
- quantity: a number between 0 and 999. The purpose of
this value is to change quantity of the product item. If quantity is 0,
the product item is removed.
- optionItems/optionValueId: a valid option value
ID. The purpose of this value is to exchange an option value for an
option item of an option product.
This is only possible if the product item is an option product. To change
option values a collection of option items to be changed need to be
provided in property optionItems. Those
optionItems need to contain optionId
and optionValueId. The provided values must be valid
for the option product that this product item represents. Otherwise
InvalidProductOptionItemException or
InvalidProductOptionValueItemException will be thrown.
custom properties c_\<CUSTOM_NAME\>: a
value corresponding to the type defined for custom attribute
\<CUSTOM_NAME\> of ProductLineItem. The purpose of this value is to
add or change the value of a custom attribute defined for
ProductLineItem.
    *
    * If you would like to get a raw Response object use the other updateItemInBasket function.
    *
    * @param options - An object containing the options for this method.
    * @param parameters - An object containing the parameters for this method.
    * @param organizationId - An identifier for the organization the request is being made by.
    * @param basketId - The ID of the basket to be modified.
    * @param itemId - The ID of the item to be updated.
    * @param siteId -
    * @param headers - An object literal of key value pairs of the headers to be
    * sent with this request.
    * @param body - The data to send as the request body.
    *
    * @returns A promise of type ShopperBaskets.Basket.
    */
  updateItemInBasket(options: {
    parameters?: {
      organizationId?: string;
      basketId: string;
      itemId: string;
      siteId?: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
    body: ShopperBaskets.ProductItem;
  }): Promise<ShopperBaskets.Basket>;
  /**
    * Updates an item in a basket. The
following values in the request body are considered by the server:

- productId: a valid product ID. The purpose of this
value is to exchange a variation of a variation product.
- shipmentId: a valid shipment ID. The purpose of
this value is to move a product item to another shipment.
- quantity: a number between 0 and 999. The purpose of
this value is to change quantity of the product item. If quantity is 0,
the product item is removed.
- optionItems/optionValueId: a valid option value
ID. The purpose of this value is to exchange an option value for an
option item of an option product.
This is only possible if the product item is an option product. To change
option values a collection of option items to be changed need to be
provided in property optionItems. Those
optionItems need to contain optionId
and optionValueId. The provided values must be valid
for the option product that this product item represents. Otherwise
InvalidProductOptionItemException or
InvalidProductOptionValueItemException will be thrown.
custom properties c_\<CUSTOM_NAME\>: a
value corresponding to the type defined for custom attribute
\<CUSTOM_NAME\> of ProductLineItem. The purpose of this value is to
add or change the value of a custom attribute defined for
ProductLineItem.
    *
    * @param options - An object containing the options for this method.
    * @param parameters - An object containing the parameters for this method.
    * @param organizationId - An identifier for the organization the request is being made by.
    * @param basketId - The ID of the basket to be modified.
    * @param itemId - The ID of the item to be updated.
    * @param siteId -
    * @param headers - An object literal of key value pairs of the headers to be
    * sent with this request.
    * @param body - The data to send as the request body.
    * @param rawResponse - Set to true to return entire Response object instead of DTO.
    *
    * @returns A promise of type Response if rawResponse is true, a promise of type ShopperBaskets.Basket otherwise.
    */
  updateItemInBasket<T extends boolean>(
    options: {
      parameters?: {
        organizationId?: string;
        basketId: string;
        itemId: string;
        siteId?: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
      body: ShopperBaskets.ProductItem;
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : ShopperBaskets.Basket>;
  /**
   * This method allows you to apply external taxation data to an existing basket to be able to pass tax rates and optional values for a specific taxable line item. This endpoint can be called only if external taxation mode was used for basket creation. See POST /baskets for more information.
   *
   * If you would like to get a raw Response object use the other addTaxesForBasketItem function.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId - An identifier for the organization the request is being made by.
   * @param basketId - The ID of the basket to be modified.
   * @param itemId - The ID of the item to be updated.
   * @param siteId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param body - The data to send as the request body.
   *
   * @returns A promise of type void.
   */
  addTaxesForBasketItem(options: {
    parameters?: {
      organizationId?: string;
      basketId: string;
      itemId: string;
      siteId?: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
    body: object;
  }): Promise<void>;
  /**
   * This method allows you to apply external taxation data to an existing basket to be able to pass tax rates and optional values for a specific taxable line item. This endpoint can be called only if external taxation mode was used for basket creation. See POST /baskets for more information.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId - An identifier for the organization the request is being made by.
   * @param basketId - The ID of the basket to be modified.
   * @param itemId - The ID of the item to be updated.
   * @param siteId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param body - The data to send as the request body.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type void otherwise.
   */
  addTaxesForBasketItem<T extends boolean>(
    options: {
      parameters?: {
        organizationId?: string;
        basketId: string;
        itemId: string;
        siteId?: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
      body: object;
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : void>;
  /**
   * Adds a payment instrument to a basket.
   *
   * If you would like to get a raw Response object use the other addPaymentInstrumentToBasket function.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId - An identifier for the organization the request is being made by.
   * @param basketId - The ID of the basket to be modified.
   * @param siteId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param body - The data to send as the request body.
   *
   * @returns A promise of type ShopperBaskets.Basket.
   */
  addPaymentInstrumentToBasket(options: {
    parameters?: {
      organizationId?: string;
      basketId: string;
      siteId?: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
    body: ShopperBaskets.BasketPaymentInstrumentRequest;
  }): Promise<ShopperBaskets.Basket>;
  /**
   * Adds a payment instrument to a basket.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId - An identifier for the organization the request is being made by.
   * @param basketId - The ID of the basket to be modified.
   * @param siteId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param body - The data to send as the request body.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type ShopperBaskets.Basket otherwise.
   */
  addPaymentInstrumentToBasket<T extends boolean>(
    options: {
      parameters?: {
        organizationId?: string;
        basketId: string;
        siteId?: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
      body: ShopperBaskets.BasketPaymentInstrumentRequest;
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : ShopperBaskets.Basket>;
  /**
   * Removes a payment instrument of a basket.
   *
   * If you would like to get a raw Response object use the other removePaymentInstrumentFromBasket function.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId - An identifier for the organization the request is being made by.
   * @param basketId - The ID of the basket to be modified.
   * @param paymentInstrumentId -
   * @param siteId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   *
   * @returns A promise of type ShopperBaskets.Basket.
   */
  removePaymentInstrumentFromBasket(options?: {
    parameters?: {
      organizationId?: string;
      basketId: string;
      paymentInstrumentId: string;
      siteId?: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
  }): Promise<ShopperBaskets.Basket>;
  /**
   * Removes a payment instrument of a basket.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId - An identifier for the organization the request is being made by.
   * @param basketId - The ID of the basket to be modified.
   * @param paymentInstrumentId -
   * @param siteId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type ShopperBaskets.Basket otherwise.
   */
  removePaymentInstrumentFromBasket<T extends boolean>(
    options?: {
      parameters?: {
        organizationId?: string;
        basketId: string;
        paymentInstrumentId: string;
        siteId?: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : ShopperBaskets.Basket>;
  /**
   * Gets applicable payment methods for an existing basket considering the open payment amount only.
   *
   * If you would like to get a raw Response object use the other getPaymentMethodsForBasket function.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId - An identifier for the organization the request is being made by.
   * @param basketId - The ID of the basket to be modified.
   * @param siteId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   *
   * @returns A promise of type ShopperBaskets.PaymentMethodResult.
   */
  getPaymentMethodsForBasket(options?: {
    parameters?: {
      organizationId?: string;
      basketId: string;
      siteId?: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
  }): Promise<ShopperBaskets.PaymentMethodResult>;
  /**
   * Gets applicable payment methods for an existing basket considering the open payment amount only.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId - An identifier for the organization the request is being made by.
   * @param basketId - The ID of the basket to be modified.
   * @param siteId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type ShopperBaskets.PaymentMethodResult otherwise.
   */
  getPaymentMethodsForBasket<T extends boolean>(
    options?: {
      parameters?: {
        organizationId?: string;
        basketId: string;
        siteId?: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : ShopperBaskets.PaymentMethodResult>;
  /**
    * Creates a new shipment for a basket.

The created shipment is initialized with values provided in the body
document and can be updated with further data API calls. Considered from
the body are the following properties if specified:

- the ID
- the shipping address
- the shipping method
- gift boolean flag
- gift message
- custom properties
    *
    * If you would like to get a raw Response object use the other createShipmentForBasket function.
    *
    * @param options - An object containing the options for this method.
    * @param parameters - An object containing the parameters for this method.
    * @param organizationId - An identifier for the organization the request is being made by.
    * @param basketId - The ID of the basket to be modified.
    * @param siteId -
    * @param headers - An object literal of key value pairs of the headers to be
    * sent with this request.
    * @param body - The data to send as the request body.
    *
    * @returns A promise of type ShopperBaskets.Basket.
    */
  createShipmentForBasket(options: {
    parameters?: {
      organizationId?: string;
      basketId: string;
      siteId?: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
    body: ShopperBaskets.Shipment;
  }): Promise<ShopperBaskets.Basket>;
  /**
    * Creates a new shipment for a basket.

The created shipment is initialized with values provided in the body
document and can be updated with further data API calls. Considered from
the body are the following properties if specified:

- the ID
- the shipping address
- the shipping method
- gift boolean flag
- gift message
- custom properties
    *
    * @param options - An object containing the options for this method.
    * @param parameters - An object containing the parameters for this method.
    * @param organizationId - An identifier for the organization the request is being made by.
    * @param basketId - The ID of the basket to be modified.
    * @param siteId -
    * @param headers - An object literal of key value pairs of the headers to be
    * sent with this request.
    * @param body - The data to send as the request body.
    * @param rawResponse - Set to true to return entire Response object instead of DTO.
    *
    * @returns A promise of type Response if rawResponse is true, a promise of type ShopperBaskets.Basket otherwise.
    */
  createShipmentForBasket<T extends boolean>(
    options: {
      parameters?: {
        organizationId?: string;
        basketId: string;
        siteId?: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
      body: ShopperBaskets.Shipment;
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : ShopperBaskets.Basket>;
  /**
    * Removes a specified shipment and all associated product, gift certificate,
shipping, and price adjustment line items from a basket.
It is not allowed to remove the default shipment.
    *
    * If you would like to get a raw Response object use the other removeShipmentFromBasket function.
    *
    * @param options - An object containing the options for this method.
    * @param parameters - An object containing the parameters for this method.
    * @param organizationId - An identifier for the organization the request is being made by.
    * @param basketId - The ID of the basket to be modified.
    * @param shipmentId - The ID of the shipment to be modified.
    * @param siteId -
    * @param headers - An object literal of key value pairs of the headers to be
    * sent with this request.
    *
    * @returns A promise of type ShopperBaskets.Basket.
    */
  removeShipmentFromBasket(options?: {
    parameters?: {
      organizationId?: string;
      basketId: string;
      shipmentId: string;
      siteId?: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
  }): Promise<ShopperBaskets.Basket>;
  /**
    * Removes a specified shipment and all associated product, gift certificate,
shipping, and price adjustment line items from a basket.
It is not allowed to remove the default shipment.
    *
    * @param options - An object containing the options for this method.
    * @param parameters - An object containing the parameters for this method.
    * @param organizationId - An identifier for the organization the request is being made by.
    * @param basketId - The ID of the basket to be modified.
    * @param shipmentId - The ID of the shipment to be modified.
    * @param siteId -
    * @param headers - An object literal of key value pairs of the headers to be
    * sent with this request.
    * @param rawResponse - Set to true to return entire Response object instead of DTO.
    *
    * @returns A promise of type Response if rawResponse is true, a promise of type ShopperBaskets.Basket otherwise.
    */
  removeShipmentFromBasket<T extends boolean>(
    options?: {
      parameters?: {
        organizationId?: string;
        basketId: string;
        shipmentId: string;
        siteId?: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : ShopperBaskets.Basket>;
  /**
    * Updates a shipment for a basket.

The shipment is initialized with values provided in the body
document and can be updated with further data API calls. Considered from
the body are the following properties if specified:
- the ID
- the shipping address
- the shipping method
- gift boolean flag
- gift message
- custom properties
    *
    * If you would like to get a raw Response object use the other updateShipmentForBasket function.
    *
    * @param options - An object containing the options for this method.
    * @param parameters - An object containing the parameters for this method.
    * @param organizationId - An identifier for the organization the request is being made by.
    * @param basketId - The ID of the basket to be modified.
    * @param shipmentId - The ID of the shipment to be modified.
    * @param siteId -
    * @param headers - An object literal of key value pairs of the headers to be
    * sent with this request.
    * @param body - The data to send as the request body.
    *
    * @returns A promise of type ShopperBaskets.Basket.
    */
  updateShipmentForBasket(options: {
    parameters?: {
      organizationId?: string;
      basketId: string;
      shipmentId: string;
      siteId?: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
    body: ShopperBaskets.Shipment;
  }): Promise<ShopperBaskets.Basket>;
  /**
    * Updates a shipment for a basket.

The shipment is initialized with values provided in the body
document and can be updated with further data API calls. Considered from
the body are the following properties if specified:
- the ID
- the shipping address
- the shipping method
- gift boolean flag
- gift message
- custom properties
    *
    * @param options - An object containing the options for this method.
    * @param parameters - An object containing the parameters for this method.
    * @param organizationId - An identifier for the organization the request is being made by.
    * @param basketId - The ID of the basket to be modified.
    * @param shipmentId - The ID of the shipment to be modified.
    * @param siteId -
    * @param headers - An object literal of key value pairs of the headers to be
    * sent with this request.
    * @param body - The data to send as the request body.
    * @param rawResponse - Set to true to return entire Response object instead of DTO.
    *
    * @returns A promise of type Response if rawResponse is true, a promise of type ShopperBaskets.Basket otherwise.
    */
  updateShipmentForBasket<T extends boolean>(
    options: {
      parameters?: {
        organizationId?: string;
        basketId: string;
        shipmentId: string;
        siteId?: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
      body: ShopperBaskets.Shipment;
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : ShopperBaskets.Basket>;
  /**
   * Sets a shipping address of a specific shipment of a basket.
   *
   * If you would like to get a raw Response object use the other updateShippingAddressForShipment function.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId - An identifier for the organization the request is being made by.
   * @param basketId - The ID of the basket to be modified.
   * @param shipmentId - The ID of the shipment to be modified.
   * @param useAsBilling -
   * @param siteId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param body - The data to send as the request body.
   *
   * @returns A promise of type ShopperBaskets.Basket.
   */
  updateShippingAddressForShipment(options: {
    parameters?: {
      organizationId?: string;
      basketId: string;
      shipmentId: string;
      useAsBilling?: boolean;
      siteId?: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
    body: ShopperBaskets.OrderAddress;
  }): Promise<ShopperBaskets.Basket>;
  /**
   * Sets a shipping address of a specific shipment of a basket.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId - An identifier for the organization the request is being made by.
   * @param basketId - The ID of the basket to be modified.
   * @param shipmentId - The ID of the shipment to be modified.
   * @param useAsBilling -
   * @param siteId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param body - The data to send as the request body.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type ShopperBaskets.Basket otherwise.
   */
  updateShippingAddressForShipment<T extends boolean>(
    options: {
      parameters?: {
        organizationId?: string;
        basketId: string;
        shipmentId: string;
        useAsBilling?: boolean;
        siteId?: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
      body: ShopperBaskets.OrderAddress;
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : ShopperBaskets.Basket>;
  /**
   * Sets a shipping method to a specific shipment of a basket.
   *
   * If you would like to get a raw Response object use the other updateShippingMethodForShipment function.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId - An identifier for the organization the request is being made by.
   * @param basketId - The ID of the basket to be modified.
   * @param shipmentId - The ID of the shipment to be modified.
   * @param siteId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param body - The data to send as the request body.
   *
   * @returns A promise of type ShopperBaskets.Basket.
   */
  updateShippingMethodForShipment(options: {
    parameters?: {
      organizationId?: string;
      basketId: string;
      shipmentId: string;
      siteId?: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
    body: ShopperBaskets.ShippingMethod;
  }): Promise<ShopperBaskets.Basket>;
  /**
   * Sets a shipping method to a specific shipment of a basket.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId - An identifier for the organization the request is being made by.
   * @param basketId - The ID of the basket to be modified.
   * @param shipmentId - The ID of the shipment to be modified.
   * @param siteId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param body - The data to send as the request body.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type ShopperBaskets.Basket otherwise.
   */
  updateShippingMethodForShipment<T extends boolean>(
    options: {
      parameters?: {
        organizationId?: string;
        basketId: string;
        shipmentId: string;
        siteId?: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
      body: ShopperBaskets.ShippingMethod;
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : ShopperBaskets.Basket>;
  /**
   * Gets the applicable shipping methods for a certain shipment of a basket.
   *
   * If you would like to get a raw Response object use the other getShippingMethodsForShipment function.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId - An identifier for the organization the request is being made by.
   * @param basketId - The ID of the basket to be modified.
   * @param shipmentId - The ID of the shipment to be modified.
   * @param siteId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   *
   * @returns A promise of type ShopperBaskets.ShippingMethodResult.
   */
  getShippingMethodsForShipment(options?: {
    parameters?: {
      organizationId?: string;
      basketId: string;
      shipmentId: string;
      siteId?: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
  }): Promise<ShopperBaskets.ShippingMethodResult>;
  /**
   * Gets the applicable shipping methods for a certain shipment of a basket.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId - An identifier for the organization the request is being made by.
   * @param basketId - The ID of the basket to be modified.
   * @param shipmentId - The ID of the shipment to be modified.
   * @param siteId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type ShopperBaskets.ShippingMethodResult otherwise.
   */
  getShippingMethodsForShipment<T extends boolean>(
    options?: {
      parameters?: {
        organizationId?: string;
        basketId: string;
        shipmentId: string;
        siteId?: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : ShopperBaskets.ShippingMethodResult>;
  /**
   * This method gives you the external taxation data set by the PUT taxes API. This endpoint can be called only if external taxation mode was used for basket creation. See POST /baskets for more information.
   *
   * If you would like to get a raw Response object use the other getTaxesFromBasket function.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId - An identifier for the organization the request is being made by.
   * @param basketId - The ID of the basket to be modified.
   * @param siteId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   *
   * @returns A promise of type ShopperBaskets.Taxes.
   */
  getTaxesFromBasket(options?: {
    parameters?: {
      organizationId?: string;
      basketId: string;
      siteId?: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
  }): Promise<ShopperBaskets.Taxes>;
  /**
   * This method gives you the external taxation data set by the PUT taxes API. This endpoint can be called only if external taxation mode was used for basket creation. See POST /baskets for more information.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId - An identifier for the organization the request is being made by.
   * @param basketId - The ID of the basket to be modified.
   * @param siteId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type ShopperBaskets.Taxes otherwise.
   */
  getTaxesFromBasket<T extends boolean>(
    options?: {
      parameters?: {
        organizationId?: string;
        basketId: string;
        siteId?: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : ShopperBaskets.Taxes>;
  /**
   * This method allows you to apply external taxation data to an existing basket to be able to pass tax rates and optional values for all taxable line items. This endpoint can be called only if external taxation mode was used for basket creation. See POST /baskets for more information.
   *
   * If you would like to get a raw Response object use the other addTaxesForBasket function.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId - An identifier for the organization the request is being made by.
   * @param basketId - The ID of the basket to be modified.
   * @param siteId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param body - The data to send as the request body.
   *
   * @returns A promise of type void.
   */
  addTaxesForBasket(options: {
    parameters?: {
      organizationId?: string;
      basketId: string;
      siteId?: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
    body: ShopperBaskets.Taxes;
  }): Promise<void>;
  /**
   * This method allows you to apply external taxation data to an existing basket to be able to pass tax rates and optional values for all taxable line items. This endpoint can be called only if external taxation mode was used for basket creation. See POST /baskets for more information.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId - An identifier for the organization the request is being made by.
   * @param basketId - The ID of the basket to be modified.
   * @param siteId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param body - The data to send as the request body.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type void otherwise.
   */
  addTaxesForBasket<T extends boolean>(
    options: {
      parameters?: {
        organizationId?: string;
        basketId: string;
        siteId?: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
      body: ShopperBaskets.Taxes;
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : void>;
}
