/*
 * Copyright (c) 2020, salesforce.com, inc.
 * All rights reserved.
 * SPDX-License-Identifier: BSD-3-Clause
 * For full license text, see the LICENSE file in the repo root or https://opensource.org/licenses/BSD-3-Clause
 */
import { BaseClient, ClientConfig, Response } from "@commerce-apps/core";
import { OperationOptions } from "retry";
export declare namespace ShopperOrders {
  type ErrorResponse = {
    type: string;
    title?: string;
    detail?: string;
    instance?: string;
  } & {
    [key: string]: any;
  };
  type TaxItems = {
    taxItems?: Array<object>;
  } & {
    [key: string]: any;
  };
  type PaymentCardSpec = {
    name?: string;
    numberLengths?: Array<string>;
    checksumVerificationEnabled?: boolean;
    numberPrefixes?: Array<string>;
    image?: string;
    cardType?: string;
    description?: string;
  } & {
    [key: string]: any;
  };
  type OrderAddress = {
    address1?: string;
    countryCode?: string;
    suffix?: string;
    jobTitle?: string;
    lastName?: string;
    fullName?: string;
    companyName?: string;
    id?: string;
    title?: string;
    firstName?: string;
    stateCode?: string;
    postBox?: string;
    secondName?: string;
    salutation?: string;
    phone?: string;
    suite?: string;
    city?: string;
    address2?: string;
    postalCode?: string;
  } & {
    [key: string]: any;
  };
  type BasketsResult = {
    baskets: Array<object>;
    total: number;
  } & {
    [key: string]: any;
  };
  type PaymentCard = {
    creditCardExpired?: boolean;
    validFromMonth?: number;
    creditCardToken?: string;
    expirationYear?: number;
    expirationMonth?: number;
    numberLastDigits?: string;
    cardType?: string;
    maskedNumber?: string;
    holder?: string;
    issueNumber?: string;
    validFromYear?: number;
  };
  type NotesResult = {
    notes?: Array<object>;
  } & {
    [key: string]: any;
  };
  type ShippingItem = {
    priceAdjustments?: Array<object>;
    taxBasis?: number;
    basePrice?: number;
    adjustedTax?: number;
    priceAfterItemDiscount?: number;
    taxRate?: number;
    itemText?: string;
    taxClassId?: string;
    itemId?: string;
    shipmentId?: string;
    price?: number;
    tax?: number;
  } & {
    [key: string]: any;
  };
  type Discount = {
    priceBookId?: string;
    amount?: number;
    type: string;
    percentage?: number;
  } & {
    [key: string]: any;
  };
  type Note = {
    subject?: string;
    createdBy?: string;
    id?: string;
    text?: string;
    creationDate?: any;
  };
  type CouponItem = {
    valid?: boolean;
    code: string;
    statusCode?: string;
    couponItemId?: string;
  } & {
    [key: string]: any;
  };
  type PromotionLink = {
    promotionId?: string;
    name?: string;
    title?: string;
    calloutMsg?: string;
  };
  type ShippingPromotion = {
    promotionName?: string;
    promotionId?: string;
    calloutMsg?: string;
  } & {
    [key: string]: any;
  };
  type ProductItem = {
    priceAdjustments?: Array<object>;
    taxBasis?: number;
    basePrice?: number;
    priceAfterOrderDiscount?: number;
    bundledProductItems?: Array<any>;
    adjustedTax?: number;
    taxRate?: number;
    priceAfterItemDiscount?: number;
    optionItems?: Array<object>;
    itemText?: string;
    taxClassId?: string;
    productListItem?: {
      productList?: {
        description?: string;
        name?: string;
        public?: boolean;
        title?: string;
        type?: string;
      } & {
        [key: string]: any;
      };
      productDetailsLink?: {
        title?: string;
        productDescription?: string;
        productId: string;
        productName?: string;
      };
      id: string;
      purchasedQuantity?: number;
      public?: boolean;
      type?: string;
      priority?: number;
      quantity?: number;
    };
    gift?: boolean;
    itemId?: string;
    productId?: string;
    shipmentId?: string;
    inventoryId?: string;
    shippingItemId?: string;
    giftMessage?: string;
    bonusProductLineItem?: boolean;
    price?: number;
    bonusDiscountLineItemId?: string;
    tax?: number;
    productName?: string;
    quantity?: number;
  } & {
    [key: string]: any;
  };
  type BasketPaymentInstrumentRequest = {
    bankRoutingNumber?: string;
    amount?: number;
    paymentMethodId?: string;
    giftCertificateCode?: string;
    paymentCard?: {
      validFromMonth?: number;
      creditCardToken?: string;
      expirationYear?: number;
      expirationMonth?: number;
      cardType?: string;
      maskedNumber?: string;
      holder?: string;
      issueNumber?: string;
      validFromYear?: number;
    };
  } & {
    [key: string]: any;
  };
  type Taxes = {
    taxes: {} & {
      [key: string]: any;
    };
  };
  type OrderPaymentInstrument = {
    amount?: number;
    authorizationStatus?: {
      code?: string;
      message?: string;
      status?: number;
    };
    bankRoutingNumber?: string;
    maskedGiftCertificateCode?: string;
    paymentCard?: {
      creditCardExpired?: boolean;
      validFromMonth?: number;
      creditCardToken?: string;
      expirationYear?: number;
      expirationMonth?: number;
      numberLastDigits?: string;
      cardType?: string;
      maskedNumber?: string;
      holder?: string;
      issueNumber?: string;
      validFromYear?: number;
    };
    paymentInstrumentId?: string;
    paymentMethodId?: string;
  } & {
    [key: string]: any;
  };
  type BonusDiscountLineItem = {
    promotionId?: string;
    id?: string;
    bonusProducts?: Array<object>;
    couponCode?: string;
    maxBonusItems?: number;
  } & {
    [key: string]: any;
  };
  type PaymentMethodResult = {
    applicablePaymentMethods?: Array<object>;
  } & {
    [key: string]: any;
  };
  type Shipment = {
    shippingStatus?: string;
    productTotal?: number;
    shipmentNo?: string;
    productSubTotal?: number;
    shippingTotal?: number;
    merchandizeTotalTax?: number;
    trackingNumber?: string;
    shippingTotalTax?: number;
    shippingMethod?: {
      name?: string;
      shippingPromotions?: Array<object>;
      externalShippingMethod?: string;
      id: string;
      price?: number;
      description?: string;
    } & {
      [key: string]: any;
    };
    gift?: boolean;
    shippingAddress?: {
      address1?: string;
      countryCode?: string;
      suffix?: string;
      jobTitle?: string;
      lastName?: string;
      fullName?: string;
      companyName?: string;
      id?: string;
      title?: string;
      firstName?: string;
      stateCode?: string;
      postBox?: string;
      secondName?: string;
      salutation?: string;
      phone?: string;
      city?: string;
      suite?: string;
      address2?: string;
      postalCode?: string;
    } & {
      [key: string]: any;
    };
    taxTotal?: number;
    shipmentId?: string;
    adjustedMerchandizeTotalTax?: number;
    adjustedShippingTotalTax?: number;
    giftMessage?: string;
    shipmentTotal?: number;
  } & {
    [key: string]: any;
  };
  type CustomerInfo = {
    customerName?: string;
    customerNo?: string;
    email: string;
    customerId?: string;
  } & {
    [key: string]: any;
  };
  type SimpleLink = {};
  type PriceAdjustment = {
    appliedDiscount?: {
      priceBookId?: string;
      amount?: number;
      type: string;
      percentage?: number;
    } & {
      [key: string]: any;
    };
    lastModified?: any;
    promotionId?: string;
    createdBy?: string;
    custom?: boolean;
    itemText?: string;
    manual?: boolean;
    priceAdjustmentId?: string;
    couponCode?: string;
    price?: number;
    creationDate?: any;
    promotionLink?: string;
    reasonCode?: string;
  } & {
    [key: string]: any;
  };
  type ShippingMethodResult = {
    applicableShippingMethods?: Array<object>;
    defaultShippingMethodId?: string;
  } & {
    [key: string]: any;
  };
  type ProductDetailsLink = {
    title?: string;
    productDescription?: string;
    productId: string;
    productName?: string;
  };
  type OptionItem = {
    taxBasis?: number;
    priceAdjustments?: Array<object>;
    basePrice?: number;
    priceAfterOrderDiscount?: number;
    bundledProductItems?: Array<any>;
    adjustedTax?: number;
    taxRate?: number;
    priceAfterItemDiscount?: number;
    optionItems?: Array<any>;
    taxClassId?: string;
    itemText?: string;
    productListItem?: {
      productList?: {
        description?: string;
        name?: string;
        public?: boolean;
        title?: string;
        type?: string;
      } & {
        [key: string]: any;
      };
      productDetailsLink?: {
        title?: string;
        productDescription?: string;
        productId: string;
        productName?: string;
      };
      id: string;
      purchasedQuantity?: number;
      public?: boolean;
      type?: string;
      priority?: number;
      quantity?: number;
    };
    gift?: boolean;
    itemId?: string;
    productId?: string;
    optionId: string;
    shipmentId?: string;
    inventoryId?: string;
    shippingItemId?: string;
    giftMessage?: string;
    bonusProductLineItem?: boolean;
    optionValueId: string;
    price?: number;
    bonusDiscountLineItemId?: string;
    tax?: number;
    productName?: string;
    quantity?: number;
  } & {
    [key: string]: any;
  };
  type ShippingMethod = {
    name?: string;
    shippingPromotions?: Array<object>;
    externalShippingMethod?: string;
    id: string;
    price?: number;
    description?: string;
  } & {
    [key: string]: any;
  };
  type Basket = {
    shipments?: Array<object>;
    giftCertificateItems?: Array<object>;
    bonusDiscountLineItems?: Array<object>;
    productTotal?: number;
    sourceCode?: string;
    lastModified?: any;
    agentBasket?: boolean;
    productSubTotal?: number;
    couponItems?: Array<object>;
    shippingItems?: Array<object>;
    shippingTotal?: number;
    customerInfo?: {
      customerName?: string;
      customerNo?: string;
      email: string;
      customerId?: string;
    } & {
      [key: string]: any;
    };
    merchandizeTotalTax?: number;
    shippingTotalTax?: number;
    taxation?: string;
    paymentInstruments?: Array<object>;
    notes?: {};
    inventoryReservationExpiry?: any;
    taxTotal?: number;
    orderTotal?: number;
    currency?: string;
    adjustedShippingTotalTax?: number;
    adjustedMerchandizeTotalTax?: number;
    basketId?: string;
    billingAddress?: {
      address1?: string;
      countryCode?: string;
      suffix?: string;
      jobTitle?: string;
      lastName?: string;
      fullName?: string;
      companyName?: string;
      id?: string;
      title?: string;
      firstName?: string;
      stateCode?: string;
      postBox?: string;
      secondName?: string;
      salutation?: string;
      phone?: string;
      suite?: string;
      city?: string;
      address2?: string;
      postalCode?: string;
    } & {
      [key: string]: any;
    };
    creationDate?: any;
    productItems?: Array<object>;
    orderPriceAdjustments?: Array<object>;
    channelType?: string;
  } & {
    [key: string]: any;
  };
  type OrderPaymentInstrumentRequest = {
    bankRoutingNumber?: string;
    amount?: number;
    paymentMethodId?: string;
    giftCertificateCode?: string;
    paymentCard?: {
      creditCardToken?: string;
      validFromMonth?: number;
      expirationMonth?: number;
      expirationYear?: number;
      cardType?: string;
      holder?: string;
      maskedNumber?: string;
      issueNumber?: string;
      validFromYear?: number;
    };
  } & {
    [key: string]: any;
  };
  type GiftCertificateItem = {
    recipientName?: string;
    senderName?: string;
    recipientEmail: string;
    amount: number;
    shipmentId?: string;
    message?: string;
    giftCertificateItemId?: string;
  } & {
    [key: string]: any;
  };
  type ProductListLink = {
    description?: string;
    name?: string;
    public?: boolean;
    title?: string;
    type?: string;
  } & {
    [key: string]: any;
  };
  type Order = {
    adjustedMerchandizeTotalTax?: number;
    adjustedShippingTotalTax?: number;
    billingAddress?: {
      address1?: string;
      countryCode?: string;
      suffix?: string;
      jobTitle?: string;
      lastName?: string;
      fullName?: string;
      companyName?: string;
      id?: string;
      title?: string;
      firstName?: string;
      stateCode?: string;
      postBox?: string;
      secondName?: string;
      salutation?: string;
      phone?: string;
      suite?: string;
      city?: string;
      address2?: string;
      postalCode?: string;
    } & {
      [key: string]: any;
    };
    bonusDiscountLineItems?: Array<object>;
    channelType?: string;
    confirmationStatus?: string;
    couponItems?: Array<object>;
    createdBy?: string;
    creationDate?: any;
    currency?: string;
    customerInfo?: {
      customerName?: string;
      customerNo?: string;
      email: string;
      customerId?: string;
    } & {
      [key: string]: any;
    };
    customerName?: string;
    exportStatus?: string;
    externalOrderStatus?: string;
    giftCertificateItems?: Array<object>;
    globalPartyId?: string;
    lastModified?: any;
    merchandizeTotalTax?: number;
    notes?: {};
    orderNo?: string;
    orderPriceAdjustments?: Array<object>;
    orderToken?: string;
    orderTotal?: number;
    paymentInstruments?: Array<object>;
    paymentStatus?: string;
    productItems?: Array<object>;
    productSubTotal?: number;
    productTotal?: number;
    shipments?: Array<object>;
    shippingItems?: Array<object>;
    shippingStatus?: string;
    shippingTotal?: number;
    shippingTotalTax?: number;
    siteId?: string;
    sourceCode?: string;
    status?: string;
    taxTotal?: number;
    taxation?: string;
  } & {
    [key: string]: any;
  };
  type OrderPaymentCardRequest = {
    validFromMonth?: number;
    creditCardToken?: string;
    expirationYear?: number;
    expirationMonth?: number;
    cardType?: string;
    maskedNumber?: string;
    holder?: string;
    issueNumber?: string;
    validFromYear?: number;
  };
  type PaymentMethod = {
    name?: string;
    id: string;
    image?: string;
    paymentProcessorId?: string;
    description?: string;
    cards?: Array<object>;
  } & {
    [key: string]: any;
  };
  type TaxItem = {
    id: string;
    value?: number;
    rate: number;
  };
  type Status = {
    code?: string;
    message?: string;
    status?: number;
  };
  type ProductListItemReference = {
    productList?: {
      description?: string;
      name?: string;
      public?: boolean;
      title?: string;
      type?: string;
    } & {
      [key: string]: any;
    };
    productDetailsLink?: {
      title?: string;
      productDescription?: string;
      productId: string;
      productName?: string;
    };
    id: string;
    purchasedQuantity?: number;
    public?: boolean;
    type?: string;
    priority?: number;
    quantity?: number;
  };
  type Money = {
    currencyMnemonic?: string;
    value?: number;
  } & {
    [key: string]: any;
  };
  type SimpleSearchResult = {
    limit: number;
    hits?: Array<object>;
    offset: number;
    total: number;
  } & {
    [key: string]: any;
  };
  type SearchRequest = {
    limit?: number;
    query: any;
    sorts?: Array<object>;
    offset?: number;
  } & {
    [key: string]: any;
  };
  type PaginatedSearchResult = {
    sorts?: Array<object>;
    hits?: Array<object>;
    query: any;
    limit: number;
    offset: number;
    total: number;
  } & {
    [key: string]: any;
  };
  type ClosedObject = {};
  type OpenObject = {} & {
    [key: string]: any;
  };
  type BoolFilter = {
    filters?: Array<any>;
    operator: string;
  } & {
    [key: string]: any;
  };
  type PaginatedSearchResultBase = {
    sorts?: Array<object>;
    hits?: Array<object>;
    query: any;
    limit: number;
    offset: number;
    total: number;
  } & {
    [key: string]: any;
  };
  type MatchAllQuery = {} & {
    [key: string]: any;
  };
  type FilteredQuery = {
    filter: any;
    query: any;
  } & {
    [key: string]: any;
  };
  type QueryFilter = {
    query: any;
  } & {
    [key: string]: any;
  };
  type Query = {
    boolQuery?: {
      must?: Array<any>;
      mustNot?: Array<any>;
      should?: Array<any>;
    } & {
      [key: string]: any;
    };
    filteredQuery?: {
      filter: any;
      query: any;
    } & {
      [key: string]: any;
    };
    matchAllQuery?: {} & {
      [key: string]: any;
    };
    nestedQuery?: {
      path: string;
      query: any;
      scoreMode?: string;
    } & {
      [key: string]: any;
    };
    termQuery?: {
      fields: Array<string>;
      operator: string;
      values?: Array<any>;
    } & {
      [key: string]: any;
    };
    textQuery?: {
      fields: Array<string>;
      searchPhrase: string;
    } & {
      [key: string]: any;
    };
  } & {
    [key: string]: any;
  };
  type TermQuery = {
    fields: Array<string>;
    operator: string;
    values?: Array<any>;
  } & {
    [key: string]: any;
  };
  type TermFilter = {
    field: string;
    operator: string;
    values?: Array<any>;
  } & {
    [key: string]: any;
  };
  type TextQuery = {
    fields: Array<string>;
    searchPhrase: string;
  } & {
    [key: string]: any;
  };
  type Range2Filter = {
    filterMode?: string;
    fromField: string;
    fromInclusive?: boolean;
    fromValue?: any;
    toField: string;
    toInclusive?: boolean;
    toValue?: any;
  } & {
    [key: string]: any;
  };
  type BoolQuery = {
    must?: Array<any>;
    mustNot?: Array<any>;
    should?: Array<any>;
  } & {
    [key: string]: any;
  };
  type SimpleSearchResultBase = {
    limit: number;
    hits?: Array<object>;
    offset: number;
    total: number;
  } & {
    [key: string]: any;
  };
  type NestedQuery = {
    path: string;
    query: any;
    scoreMode?: string;
  } & {
    [key: string]: any;
  };
  type Filter = {
    boolFilter?: {
      filters?: Array<any>;
      operator: string;
    } & {
      [key: string]: any;
    };
    queryFilter?: {
      query: any;
    } & {
      [key: string]: any;
    };
    range2Filter?: {
      filterMode?: string;
      fromField: string;
      fromInclusive?: boolean;
      fromValue?: any;
      toField: string;
      toInclusive?: boolean;
      toValue?: any;
    } & {
      [key: string]: any;
    };
    rangeFilter?: {
      field: string;
      from?: any;
      fromInclusive?: boolean;
      to?: any;
      toInclusive?: boolean;
    } & {
      [key: string]: any;
    };
    termFilter?: {
      field: string;
      operator: string;
      values?: Array<any>;
    } & {
      [key: string]: any;
    };
  } & {
    [key: string]: any;
  };
  type Sort = {
    field: string;
    sortOrder?: string;
  } & {
    [key: string]: any;
  };
  type RangeFilter = {
    field: string;
    from?: any;
    fromInclusive?: boolean;
    to?: any;
    toInclusive?: boolean;
  } & {
    [key: string]: any;
  };
  type SearchRequestBase = {
    limit?: number;
    query: any;
    sorts?: Array<object>;
    offset?: number;
  } & {
    [key: string]: any;
  };
  type NoPropertiesAllowed = {};
  type SpecifiedPropertiesAllowed = {} & {
    [key: string]: any;
  };
  type MoneyMnemonic = {
    currencyMnemonic?: string;
    value?: number;
  } & {
    [key: string]: any;
  };
}
/**
 * [Shopper Orders](https://developer.commercecloud.com/s/api-details/a003k00000UHvpFAAT)
 * ==================================
 * *Finish the shopper checkout experience resulting in an order.*<br />
 *
 * Simple example:
 *
 * ```typescript
 *   import { Checkout, ClientConfig } from "commerce-sdk";
 *   // or
 *   const { Checkout, ClientConfig } = require("commerce-sdk");
 *
 *   const clientConfig: ClientConfig = { ... };
 *   const shopperOrdersClient = new Checkout.ShopperOrders(clientConfig);
 * ```
 *
 * Example with shopper auth
 * ```typescript
 * const clientConfig: ClientConfig = {
 *   parameters: {
 *     clientId: "XXXXXX",
 *     organizationId: "XXXX",
 *     shortCode: "XXX",
 *     siteId: "XX"
 *   }
 * };
 * token = await helpers.getShopperToken(clientConfig, { type: "guest" });
 * clientConfig.headers["authorization"] = token.getBearerHeader();
 * const shopperOrdersClient = new Checkout.ShopperOrders(clientConfig);
 * ```
 *
 * <span style="font-size:.7em; display:block; text-align: right">
 * API Version: 0.0.26<br />
 * Last Updated: 2020-07-14T07:59:39.804Z<br />
 * </span>
 */
export declare class ShopperOrders extends BaseClient {
  constructor(config: ClientConfig);
  /**
   * Submits an order based on a prepared basket. The only considered value from the request body is basketId.
   *
   * If you would like to get a raw Response object use the other createOrder function.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId - An identifier for the organization the request is being made by.
   * @param siteId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param body - The data to send as the request body.
   *
   * @returns A promise of type ShopperOrders.Order.
   */
  createOrder(options: {
    parameters?: {
      organizationId?: string;
      siteId?: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
    body: ShopperOrders.Basket;
  }): Promise<ShopperOrders.Order>;
  /**
   * Submits an order based on a prepared basket. The only considered value from the request body is basketId.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId - An identifier for the organization the request is being made by.
   * @param siteId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param body - The data to send as the request body.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type ShopperOrders.Order otherwise.
   */
  createOrder<T extends boolean>(
    options: {
      parameters?: {
        organizationId?: string;
        siteId?: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
      body: ShopperOrders.Basket;
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : ShopperOrders.Order>;
  /**
   * Gets information for an order.
   *
   * If you would like to get a raw Response object use the other getOrder function.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId - An identifier for the organization the request is being made by.
   * @param orderNo - The order number of the order to be modified.
   * @param siteId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   *
   * @returns A promise of type ShopperOrders.Order.
   */
  getOrder(options?: {
    parameters?: {
      organizationId?: string;
      orderNo: string;
      siteId?: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
  }): Promise<ShopperOrders.Order>;
  /**
   * Gets information for an order.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId - An identifier for the organization the request is being made by.
   * @param orderNo - The order number of the order to be modified.
   * @param siteId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type ShopperOrders.Order otherwise.
   */
  getOrder<T extends boolean>(
    options?: {
      parameters?: {
        organizationId?: string;
        orderNo: string;
        siteId?: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : ShopperOrders.Order>;
  /**
    * Adds a payment instrument to an order.

Details:

The payment instrument is added with the provided details. The payment method must be applicable for the order see GET
/baskets/\{basketId\}/payment-methods, if the payment method is 'CREDIT_CARD' a paymentCard must be specified in the request.
    *
    * If you would like to get a raw Response object use the other createPaymentInstrumentForOrder function.
    *
    * @param options - An object containing the options for this method.
    * @param parameters - An object containing the parameters for this method.
    * @param organizationId - An identifier for the organization the request is being made by.
    * @param orderNo - The order number of the order to be modified.
    * @param siteId -
    * @param headers - An object literal of key value pairs of the headers to be
    * sent with this request.
    * @param body - The data to send as the request body.
    *
    * @returns A promise of type ShopperOrders.Order.
    */
  createPaymentInstrumentForOrder(options: {
    parameters?: {
      organizationId?: string;
      orderNo: string;
      siteId?: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
    body: ShopperOrders.OrderPaymentInstrumentRequest;
  }): Promise<ShopperOrders.Order>;
  /**
    * Adds a payment instrument to an order.

Details:

The payment instrument is added with the provided details. The payment method must be applicable for the order see GET
/baskets/\{basketId\}/payment-methods, if the payment method is 'CREDIT_CARD' a paymentCard must be specified in the request.
    *
    * @param options - An object containing the options for this method.
    * @param parameters - An object containing the parameters for this method.
    * @param organizationId - An identifier for the organization the request is being made by.
    * @param orderNo - The order number of the order to be modified.
    * @param siteId -
    * @param headers - An object literal of key value pairs of the headers to be
    * sent with this request.
    * @param body - The data to send as the request body.
    * @param rawResponse - Set to true to return entire Response object instead of DTO.
    *
    * @returns A promise of type Response if rawResponse is true, a promise of type ShopperOrders.Order otherwise.
    */
  createPaymentInstrumentForOrder<T extends boolean>(
    options: {
      parameters?: {
        organizationId?: string;
        orderNo: string;
        siteId?: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
      body: ShopperOrders.OrderPaymentInstrumentRequest;
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : ShopperOrders.Order>;
  /**
   * Removes a payment instrument of an order.
   *
   * If you would like to get a raw Response object use the other removePaymentInstrumentFromOrder function.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId - An identifier for the organization the request is being made by.
   * @param orderNo - The order number of the order to be modified.
   * @param paymentInstrumentId - the ID of the payment instrument to be updated.
   * @param siteId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   *
   * @returns A promise of type ShopperOrders.Order.
   */
  removePaymentInstrumentFromOrder(options?: {
    parameters?: {
      organizationId?: string;
      orderNo: string;
      paymentInstrumentId: string;
      siteId?: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
  }): Promise<ShopperOrders.Order>;
  /**
   * Removes a payment instrument of an order.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId - An identifier for the organization the request is being made by.
   * @param orderNo - The order number of the order to be modified.
   * @param paymentInstrumentId - the ID of the payment instrument to be updated.
   * @param siteId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type ShopperOrders.Order otherwise.
   */
  removePaymentInstrumentFromOrder<T extends boolean>(
    options?: {
      parameters?: {
        organizationId?: string;
        orderNo: string;
        paymentInstrumentId: string;
        siteId?: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : ShopperOrders.Order>;
  /**
    * Updates a payment instrument of an order.

Details:

The payment instrument is updated with the provided details. The payment method must be applicable for the
order see GET /baskets/\{basketId\}/payment-methods, if the payment method is 'CREDIT_CARD' a
paymentCard must be specified in the request.
    *
    * If you would like to get a raw Response object use the other updatePaymentInstrumentForOrder function.
    *
    * @param options - An object containing the options for this method.
    * @param parameters - An object containing the parameters for this method.
    * @param organizationId - An identifier for the organization the request is being made by.
    * @param orderNo - The order number of the order to be modified.
    * @param paymentInstrumentId - the ID of the payment instrument to be updated.
    * @param siteId -
    * @param headers - An object literal of key value pairs of the headers to be
    * sent with this request.
    * @param body - The data to send as the request body.
    *
    * @returns A promise of type ShopperOrders.Order.
    */
  updatePaymentInstrumentForOrder(options: {
    parameters?: {
      organizationId?: string;
      orderNo: string;
      paymentInstrumentId: string;
      siteId?: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
    body: ShopperOrders.OrderPaymentInstrumentRequest;
  }): Promise<ShopperOrders.Order>;
  /**
    * Updates a payment instrument of an order.

Details:

The payment instrument is updated with the provided details. The payment method must be applicable for the
order see GET /baskets/\{basketId\}/payment-methods, if the payment method is 'CREDIT_CARD' a
paymentCard must be specified in the request.
    *
    * @param options - An object containing the options for this method.
    * @param parameters - An object containing the parameters for this method.
    * @param organizationId - An identifier for the organization the request is being made by.
    * @param orderNo - The order number of the order to be modified.
    * @param paymentInstrumentId - the ID of the payment instrument to be updated.
    * @param siteId -
    * @param headers - An object literal of key value pairs of the headers to be
    * sent with this request.
    * @param body - The data to send as the request body.
    * @param rawResponse - Set to true to return entire Response object instead of DTO.
    *
    * @returns A promise of type Response if rawResponse is true, a promise of type ShopperOrders.Order otherwise.
    */
  updatePaymentInstrumentForOrder<T extends boolean>(
    options: {
      parameters?: {
        organizationId?: string;
        orderNo: string;
        paymentInstrumentId: string;
        siteId?: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
      body: ShopperOrders.OrderPaymentInstrumentRequest;
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : ShopperOrders.Order>;
  /**
   * Gets the applicable payment methods for an existing order considering the open payment amount only.
   *
   * If you would like to get a raw Response object use the other getPaymentMethodsForOrder function.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId - An identifier for the organization the request is being made by.
   * @param orderNo - The order number of the order to be modified.
   * @param siteId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   *
   * @returns A promise of type ShopperOrders.PaymentMethodResult.
   */
  getPaymentMethodsForOrder(options?: {
    parameters?: {
      organizationId?: string;
      orderNo: string;
      siteId?: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
  }): Promise<ShopperOrders.PaymentMethodResult>;
  /**
   * Gets the applicable payment methods for an existing order considering the open payment amount only.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId - An identifier for the organization the request is being made by.
   * @param orderNo - The order number of the order to be modified.
   * @param siteId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type ShopperOrders.PaymentMethodResult otherwise.
   */
  getPaymentMethodsForOrder<T extends boolean>(
    options?: {
      parameters?: {
        organizationId?: string;
        orderNo: string;
        siteId?: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : ShopperOrders.PaymentMethodResult>;
  /**
   * This method gives you the external taxation for the specified order.
   *
   * If you would like to get a raw Response object use the other getTaxesFromOrder function.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId - An identifier for the organization the request is being made by.
   * @param orderNo - The order number of the order to be modified.
   * @param siteId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   *
   * @returns A promise of type ShopperOrders.Taxes.
   */
  getTaxesFromOrder(options?: {
    parameters?: {
      organizationId?: string;
      orderNo: string;
      siteId?: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
  }): Promise<ShopperOrders.Taxes>;
  /**
   * This method gives you the external taxation for the specified order.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId - An identifier for the organization the request is being made by.
   * @param orderNo - The order number of the order to be modified.
   * @param siteId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type ShopperOrders.Taxes otherwise.
   */
  getTaxesFromOrder<T extends boolean>(
    options?: {
      parameters?: {
        organizationId?: string;
        orderNo: string;
        siteId?: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : ShopperOrders.Taxes>;
}
